==> asksuite-core-1.0.121.tgz: package/desbravador.crawler.js <==
let requestPromise = require('request-promise-native');
const Global = require('./global');


async function navigateWebsite(idHotel, checkin, checkout, adultos, criancas) {

    try {

        let options = {
            uri: Global.CRAWLER_ENDPOINT + '/desbravador',
            qs: {
                idHotel: idHotel,
                checkin: checkin,
                checkout: checkout,
                adultos: adultos,
                criancas: criancas
            },
            json: true // Automatically parses the JSON string in the response
        };

        console.log(options);

        let response = await requestPromise.get(options);

        return Promise.resolve(response);

    } catch (err) {
        console.log("caiu aqui no erro");
        console.error(err.error);
        return Promise.reject(err.error);
    }
}

navigateWebsite('GdkCNNv3dKG%2FsdqH79%2B0VT2erryEZdCDH%2BR0%2BLrdvvk0n6dMx%2FK977wbDD%2B5B%2BNyIFAkdKTQ3QUAf6tMMDruQw%3D%3D', '30-04-2018', '06-05-2018', 2, 0).then(data => {
    console.log(data);
    console.log("sucesso")
}).catch(error => {
    console.log("caiu aqui");
    console.log(error.message);
});


// navigateWebsite('hMZchDCcE01WX4P6DZcumOMmBKR5WDjutMbG2UXDRfbd%2Bo9KMummXbxjWpxiHsEHP%2B7BiWew0PRFV6RbSzWfnA%3D%3D', '31-05-2018', '02-06-2018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });


module.exports = {search: navigateWebsite};

==> asksuite-core-1.0.139.tgz: package/desbravador.crawler.js <==
let requestPromise = require('request-promise-native');
const Global = require('./global');


async function navigateWebsite(idHotel, checkin, checkout, adultos, criancas) {

    try {

        let options = {
            uri: Global.CRAWLER_ENDPOINT + '/desbravador',
            qs: {
                idHotel: idHotel,
                checkin: checkin,
                checkout: checkout,
                adultos: adultos,
                criancas: criancas
            },
            json: true // Automatically parses the JSON string in the response
        };

        console.log(options);

        let response = await requestPromise.get(options);

        return Promise.resolve(response);

    } catch (err) {
        console.log("caiu aqui no erro");
        console.error(err.error);
        return Promise.reject(err.error);
    }
}

// navigateWebsite('GdkCNNv3dKG%2FsdqH79%2B0VT2erryEZdCDH%2BR0%2BLrdvvk0n6dMx%2FK977wbDD%2B5B%2BNyIFAkdKTQ3QUAf6tMMDruQw%3D%3D', '30-04-2018', '06-05-2018', 2, 0).then(data => {
//     console.log(data);
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });


// navigateWebsite('hMZchDCcE01WX4P6DZcumOMmBKR5WDjutMbG2UXDRfbd%2Bo9KMummXbxjWpxiHsEHP%2B7BiWew0PRFV6RbSzWfnA%3D%3D', '31-05-2018', '02-06-2018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });


module.exports = {search: navigateWebsite};
